==> adminer-3.6.3.tbz: www/adminer/adminer/lang/pt.inc.php <==
<?php
$translations = array(
	'Login' => 'Entrar',
	'Logout successful.' => 'Saida bem sucedida.',
	'Invalid credentials.' => 'Identificação inválida.',
	'Server' => 'Servidor',
	'Username' => 'Usuário',
	'Password' => 'Senha',
	'Select database' => 'Selecionar Base de dados',
	'Invalid database.' => 'Base de dados inválida.',
	'Create new database' => 'Criar nova base de dados',
	'Table has been dropped.' => 'Tabela eliminada.',
	'Table has been altered.' => 'Tabela modificada.',
	'Table has been created.' => 'Tabela criada.',
	'Alter table' => 'Modificar estrutura',
	'Create table' => 'Criar tabela',
	'Table name' => 'Nome da tabela',
	'engine' => 'motor',
	'collation' => 'collation',
	'Column name' => 'Nome da coluna',
	'Type' => 'Tipo',
	'Length' => 'Tamanho',
	'Auto Increment' => 'Incremento Automático',
	'Options' => 'Opções',
	'Save' => 'Salvar',
	'Drop' => 'Remover',
	'Database has been dropped.' => 'Base de dados eliminada.',
	'Database has been created.' => 'Base de dados criada.',
	'Database has been renamed.' => 'Base de dados renomeada.',
	'Database has been altered.' => 'Base de dados modificada.',
	'Alter database' => 'Modificar Base de dados',
	'Create database' => 'Criar Base de dados',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Exportar',
	'Logout' => 'Sair',
	'database' => 'base de dados',
	'Use' => 'Usar',
	'No tables.' => 'Não existem tabelas.',
	'select' => 'registros',
	'Create new table' => 'Nova tabela',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item%s has been inserted.' => 'Registro%s inserido.',
	'Edit' => 'Modificar',
	'Insert' => 'Inserir',
	'Save and insert next' => 'Salvar e inserir outro',
	'Delete' => 'Apagar',
	'Database' => 'Base de dados',
	'Routines' => 'Procedimentos',
	'Indexes have been altered.' => 'Índices modificados.',
	'Indexes' => 'Índices',
	'Alter indexes' => 'Modificar índices',
	'Add next' => 'Adicionar proximo',
	'Language' => 'Idioma',
	'Select' => 'Selecionar',
	'New item' => 'Novo Registro',
	'Search' => 'Procurar',
	'Sort' => 'Ordenar',
	'descending' => 'decrescente',
	'Limit' => 'Limite',
	'No rows.' => 'Não existem registros.',
	'Action' => 'Ação',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta executada, %d registro afetado.', 'Consulta executada, %d registros afetados.'),
	'Error in query' => 'Erro na consulta',
	'Execute' => 'Executar',
	'Table' => 'Tabela',
	'Foreign keys' => 'Chaves foráneas',
	'Triggers' => 'Triggers',
	'View' => 'Visualizar',
	'Unable to select the table' => 'Não é possivel selecionar a Tabela',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Enviar o formulario novamente.',
	'Comment' => 'Comentário',
	'Default values' => 'Valores predeterminados',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Nenhum comando para executar.',
	'Unable to upload a file.' => 'Não é possível enviar o arquivo.',
	'File upload' => 'Importar arquivo',
	'File uploads are disabled.' => 'Importação de arquivos desablilitada.',
	'Routine has been called, %d row(s) affected.' => array('Consulta executada, %d registro afetado.', 'Consulta executada, %d registros afetados.'),
	'Call' => 'Chamar',
	'No extension' => 'Não há extension',
	'None of the supported PHP extensions (%s) are available.' => 'Nenhuma das extensões PHP suportadas (%s) está disponivel.',
	'Session support must be enabled.' => 'Devem estar habilitadas as sessões.',
	'Session expired, please login again.' => 'Sessão expirada, por favor entre sua Chave de novo.',
	'Text length' => 'Tamanho de texto',
	'Foreign key has been dropped.' => 'Chave externa eliminada.',
	'Foreign key has been altered.' => 'Chave externa modificada.',
	'Foreign key has been created.' => 'Chave externa criada.',
	'Foreign key' => 'Chave externa',
	'Target table' => 'Tabela de destino',
	'Change' => 'Modificar',
	'Source' => 'Origem',
	'Target' => 'Destino',
	'Add column' => 'Adicionar coluna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Adicionar Chave foránea',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo de índice',
	'Column (length)' => 'coluna (tamanho)',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista criada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Criar vista',
	'Name' => 'Nome',
	'Process list' => 'Lista de processos',
	'%d process(es) have been killed.' => array('%d processo terminado.', '%d processos terminados.'),
	'Kill' => 'Parar',
	'Parameter name' => 'Nome de Parâmetro',
	'Database schema' => 'Esquema de Base de dados',
	'Create procedure' => 'Criar procedimento',
	'Create function' => 'Criar função',
	'Routine has been dropped.' => 'Procedimento eliminado.',
	'Routine has been altered.' => 'Procedimento modificado.',
	'Routine has been created.' => 'Procedimento criado.',
	'Alter function' => 'Modificar Função',
	'Alter procedure' => 'Modificar procedimento',
	'Return type' => 'Tipo de valor de regreso',
	'Add trigger' => 'Adicionar trigger',
	'Trigger has been dropped.' => 'Trigger eliminado.',
	'Trigger has been altered.' => 'Trigger modificado.',
	'Trigger has been created.' => 'Trigger criado.',
	'Alter trigger' => 'Modificar Trigger',
	'Create trigger' => 'Adicionar Trigger',
	'Time' => 'Tempo',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versão %s: %s através da extensão PHP %s',
	'%d row(s)' => array('%d registro', '%d registros'),
	'Remove' => 'Remover',
	'Are you sure?' => 'Está seguro?',
	'Privileges' => 'Privilégios',
	'Create user' => 'Criar Usuário',
	'User has been dropped.' => 'Usuário eliminado.',
	'User has been altered.' => 'Usuário modificado.',
	'User has been created.' => 'Usuário criado.',
	'Hashed' => 'Hash',
	'Column' => 'Coluna',
	'Routine' => 'Rotina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduza o tamanho ou aumente a diretiva de configuração %s.',
	'Logged as: %s' => 'Logado como: %s',
	'Move up' => 'Mover acima',
	'Move down' => 'Mover abaixo',
	'Functions' => 'Funções',
	'Aggregation' => 'Adições',
	'Export' => 'Exportar',
	'Output' => 'Saída',
	'open' => 'mostrar',
	'save' => 'salvas',
	'Format' => 'Formato',
	'Tables' => 'Tabelas',
	'Data' => 'Dados',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento criado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Criar Evento',
	'At given time' => 'A hora determinada',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agenda',
	'Start' => 'Início',
	'End' => 'Fim',
	'Status' => 'Estado',
	'On completion preserve' => 'Ao completar preservar',
	'Tables and views' => 'Tabelas e vistas',
	'Data Length' => 'Tamanho de dados',
	'Index Length' => 'Tamanho de índice',
	'Data Free' => 'Espaço Livre',
	'Collation' => 'Colação',
	'Analyze' => 'Analizar',
	'Optimize' => 'Otimizar',
	'Check' => 'Verificar',
	'Repair' => 'Reparar',
	'Truncate' => 'Truncar',
	'Tables have been truncated.' => 'Tabelas truncadas (truncate).',
	'Rows' => 'Registros',
	',' => ' ',
	'Tables have been moved.' => 'As Tabelas foram movidas.',
	'Move to other database' => 'Mover outra Base de dados',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Salvar e continuar editando',
	'original' => 'original',
	'Tables have been dropped.' => 'Tabelas eliminadas.',
	'%d item(s) have been affected.' => array('%d item afetado.', '%d itens afetados.'),
	'whole result' => 'resultado completo',
	'Clone' => 'Clonar',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Quantidade máxima de campos permitidos excedidos. Por favor aumente %s e %s.',
	'Partition by' => 'Particionar por',
	'Partitions' => 'Partições',
	'Partition name' => 'Nome da Partição',
	'Values' => 'Valores',
	'%d row(s) have been imported.' => array('%d registro importado.', '%d registros importados.'),
	'anywhere' => 'qualquer local',
	'Import' => 'Importar',
	'Stop on error' => 'Parar em caso de erro',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Histórico',
	'Variables' => 'Variáveis',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'As colunas de origen e destino devem ser do mesmo tipo, deve existir um índice entre as colunas de destino e o registro referenciado deve existir.',
	'Relations' => 'Relações',
	'Run file' => 'Executar Arquivo',
	'Clear' => 'Limpar',
	'Maximum allowed file size is %sB.' => 'Tamanho máximo do arquivo é %sB.',
	'Numbers' => 'Números',
	'Date and time' => 'Data e hora',
	'Strings' => 'Cadena',
	'Binary' => 'Binário',
	'Lists' => 'Listas',
	'Editor' => 'Editor',
	'E-mail' => 'E-mail',
	'From' => 'De',
	'Subject' => 'Assunto',
	'Send' => 'Enviar',
	'%d e-mail(s) have been sent.' => array('%d email enviado.', '%d emails enviados.'),
	'Webserver file %s' => 'Arquivo do servidor web %s',
	'File does not exist.' => 'Arquivo não existe.',
	'%d in total' => '%d no total',
	'Permanent login' => 'Salvar Senha',
	'Databases have been dropped.' => 'Bases de dados eliminadas.',
	'Search data in tables' => 'Buscar dados nas Tabelas',
	'schema' => 'esquema',
	'Schema' => 'Esquema',
	'Alter schema' => 'Modificar esquema',
	'Create schema' => 'Criar esquema',
	'Schema has been dropped.' => 'Esquema eliminado.',
	'Schema has been created.' => 'Esquema criado.',
	'Schema has been altered.' => 'Esquema modificado.',
	'Sequences' => 'Sequências',
	'Create sequence' => 'Criar sequências',
	'Alter sequence' => 'Modificar sequência',
	'Sequence has been dropped.' => 'Sequência eliminada.',
	'Sequence has been created.' => 'Sequência criada.',
	'Sequence has been altered.' => 'Sequência modificada.',
	'User types' => 'Tipos definido pelo usuário',
	'Create type' => 'Criar tipo',
	'Alter type' => 'Modificar tipo',
	'Type has been dropped.' => 'Tipo eliminado.',
	'Type has been created.' => 'Tipo criado.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+clique vezes sobre o valor para edita-lo.',
	'Use edit link to modify this value.' => 'Utilize o link modificar para alterar.',
	'last' => 'último',
	'From server' => 'Desde servidor',
	'System' => 'Motor de Base de dados',
	'Select data' => 'Selecionar dados',
	'Show structure' => 'Mostrar estrutura',
	'empty' => 'vazio',
	'Network' => 'Rede',
	'Geometry' => 'Geometria',
	'File exists.' => 'Arquivo já existe.',
	'Attachments' => 'Anexos',
	'%d query(s) executed OK.' => array('%d consulta sql executada corretamente.', '%d consultas sql executadas corretamente.'),
	'Show only errors' => 'Mostrar somente erros',
	'Last page' => 'Última página',
	'Refresh' => 'Atualizar',
	'Invalid schema.' => 'Esquema inválido.',
	'Please use one of the extensions %s.' => 'Por favor use uma das extensões %s.',
	'now' => 'agora',
	'ltr' => 'ltr',
);

==> adminer-3.7.0.tbz: www/adminer/adminer/lang/pt.inc.php <==
<?php
$translations = array(
	'Login' => 'Entrar',
	'Logout successful.' => 'Saida bem sucedida.',
	'Invalid credentials.' => 'Identificação inválida.',
	'Server' => 'Servidor',
	'Username' => 'Usuário',
	'Password' => 'Senha',
	'Select database' => 'Selecionar Base de dados',
	'Invalid database.' => 'Base de dados inválida.',
	'Create new database' => 'Criar nova base de dados',
	'Table has been dropped.' => 'Tabela eliminada.',
	'Table has been altered.' => 'Tabela modificada.',
	'Table has been created.' => 'Tabela criada.',
	'Alter table' => 'Modificar estrutura',
	'Create table' => 'Criar tabela',
	'Table name' => 'Nome da tabela',
	'engine' => 'motor',
	'collation' => 'collation',
	'Column name' => 'Nome da coluna',
	'Type' => 'Tipo',
	'Length' => 'Tamanho',
	'Auto Increment' => 'Incremento Automático',
	'Options' => 'Opções',
	'Save' => 'Salvar',
	'Drop' => 'Remover',
	'Database has been dropped.' => 'Base de dados eliminada.',
	'Database has been created.' => 'Base de dados criada.',
	'Database has been renamed.' => 'Base de dados renomeada.',
	'Database has been altered.' => 'Base de dados modificada.',
	'Alter database' => 'Modificar Base de dados',
	'Create database' => 'Criar Base de dados',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Exportar',
	'Logout' => 'Sair',
	'database' => 'base de dados',
	'Use' => 'Usar',
	'No tables.' => 'Não existem tabelas.',
	'select' => 'registros',
	'Create new table' => 'Nova tabela',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item%s has been inserted.' => 'Registro%s inserido.',
	'Edit' => 'Modificar',
	'Insert' => 'Inserir',
	'Save and insert next' => 'Salvar e inserir outro',
	'Delete' => 'Apagar',
	'Database' => 'Base de dados',
	'Routines' => 'Procedimentos',
	'Indexes have been altered.' => 'Índices modificados.',
	'Indexes' => 'Índices',
	'Alter indexes' => 'Modificar índices',
	'Add next' => 'Adicionar proximo',
	'Language' => 'Idioma',
	'Select' => 'Selecionar',
	'New item' => 'Novo Registro',
	'Search' => 'Procurar',
	'Sort' => 'Ordenar',
	'descending' => 'decrescente',
	'Limit' => 'Limite',
	'No rows.' => 'Não existem registros.',
	'Action' => 'Ação',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta executada, %d registro afetado.', 'Consulta executada, %d registros afetados.'),
	'Error in query' => 'Erro na consulta',
	'Execute' => 'Executar',
	'Table' => 'Tabela',
	'Foreign keys' => 'Chaves foráneas',
	'Triggers' => 'Triggers',
	'View' => 'Visualizar',
	'Unable to select the table' => 'Não é possivel selecionar a Tabela',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Enviar o formulario novamente.',
	'Comment' => 'Comentário',
	'Default values' => 'Valores predeterminados',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Nenhum comando para executar.',
	'Unable to upload a file.' => 'Não é possível enviar o arquivo.',
	'File upload' => 'Importar arquivo',
	'File uploads are disabled.' => 'Importação de arquivos desablilitada.',
	'Routine has been called, %d row(s) affected.' => array('Consulta executada, %d registro afetado.', 'Consulta executada, %d registros afetados.'),
	'Call' => 'Chamar',
	'No extension' => 'Não há extension',
	'None of the supported PHP extensions (%s) are available.' => 'Nenhuma das extensões PHP suportadas (%s) está disponivel.',
	'Session support must be enabled.' => 'Devem estar habilitadas as sessões.',
	'Session expired, please login again.' => 'Sessão expirada, por favor entre sua Chave de novo.',
	'Text length' => 'Tamanho de texto',
	'Foreign key has been dropped.' => 'Chave externa eliminada.',
	'Foreign key has been altered.' => 'Chave externa modificada.',
	'Foreign key has been created.' => 'Chave externa criada.',
	'Foreign key' => 'Chave externa',
	'Target table' => 'Tabela de destino',
	'Change' => 'Modificar',
	'Source' => 'Origem',
	'Target' => 'Destino',
	'Add column' => 'Adicionar coluna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Adicionar Chave foránea',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo de índice',
	'Column (length)' => 'coluna (tamanho)',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista criada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Criar vista',
	'Name' => 'Nome',
	'Process list' => 'Lista de processos',
	'%d process(es) have been killed.' => array('%d processo terminado.', '%d processos terminados.'),
	'Kill' => 'Parar',
	'Parameter name' => 'Nome de Parâmetro',
	'Database schema' => 'Esquema de Base de dados',
	'Create procedure' => 'Criar procedimento',
	'Create function' => 'Criar função',
	'Routine has been dropped.' => 'Procedimento eliminado.',
	'Routine has been altered.' => 'Procedimento modificado.',
	'Routine has been created.' => 'Procedimento criado.',
	'Alter function' => 'Modificar Função',
	'Alter procedure' => 'Modificar procedimento',
	'Return type' => 'Tipo de valor de regreso',
	'Add trigger' => 'Adicionar trigger',
	'Trigger has been dropped.' => 'Trigger eliminado.',
	'Trigger has been altered.' => 'Trigger modificado.',
	'Trigger has been created.' => 'Trigger criado.',
	'Alter trigger' => 'Modificar Trigger',
	'Create trigger' => 'Adicionar Trigger',
	'Time' => 'Tempo',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versão %s: %s através da extensão PHP %s',
	'%d row(s)' => array('%d registro', '%d registros'),
	'Remove' => 'Remover',
	'Are you sure?' => 'Está seguro?',
	'Privileges' => 'Privilégios',
	'Create user' => 'Criar Usuário',
	'User has been dropped.' => 'Usuário eliminado.',
	'User has been altered.' => 'Usuário modificado.',
	'User has been created.' => 'Usuário criado.',
	'Hashed' => 'Hash',
	'Column' => 'Coluna',
	'Routine' => 'Rotina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduza o tamanho ou aumente a diretiva de configuração %s.',
	'Logged as: %s' => 'Logado como: %s',
	'Move up' => 'Mover acima',
	'Move down' => 'Mover abaixo',
	'Functions' => 'Funções',
	'Aggregation' => 'Adições',
	'Export' => 'Exportar',
	'Output' => 'Saída',
	'open' => 'mostrar',
	'save' => 'salvas',
	'Format' => 'Formato',
	'Tables' => 'Tabelas',
	'Data' => 'Dados',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento criado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Criar Evento',
	'At given time' => 'A hora determinada',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agenda',
	'Start' => 'Início',
	'End' => 'Fim',
	'Status' => 'Estado',
	'On completion preserve' => 'Ao completar preservar',
	'Tables and views' => 'Tabelas e vistas',
	'Data Length' => 'Tamanho de dados',
	'Index Length' => 'Tamanho de índice',
	'Data Free' => 'Espaço Livre',
	'Collation' => 'Colação',
	'Analyze' => 'Analizar',
	'Optimize' => 'Otimizar',
	'Check' => 'Verificar',
	'Repair' => 'Reparar',
	'Truncate' => 'Truncar',
	'Tables have been truncated.' => 'Tabelas truncadas (truncate).',
	'Rows' => 'Registros',
	',' => ' ',
	'Tables have been moved.' => 'As Tabelas foram movidas.',
	'Move to other database' => 'Mover outra Base de dados',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Salvar e continuar editando',
	'original' => 'original',
	'Tables have been dropped.' => 'Tabelas eliminadas.',
	'%d item(s) have been affected.' => array('%d item afetado.', '%d itens afetados.'),
	'whole result' => 'resultado completo',
	'Clone' => 'Clonar',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Quantidade máxima de campos permitidos excedidos. Por favor aumente %s.',
	'Partition by' => 'Particionar por',
	'Partitions' => 'Partições',
	'Partition name' => 'Nome da Partição',
	'Values' => 'Valores',
	'%d row(s) have been imported.' => array('%d registro importado.', '%d registros importados.'),
	'anywhere' => 'qualquer local',
	'Import' => 'Importar',
	'Stop on error' => 'Parar em caso de erro',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Histórico',
	'Variables' => 'Variáveis',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'As colunas de origen e destino devem ser do mesmo tipo, deve existir um índice entre as colunas de destino e o registro referenciado deve existir.',
	'Relations' => 'Relações',
	'Run file' => 'Executar Arquivo',
	'Clear' => 'Limpar',
	'Maximum allowed file size is %sB.' => 'Tamanho máximo do arquivo é %sB.',
	'Numbers' => 'Números',
	'Date and time' => 'Data e hora',
	'Strings' => 'Cadena',
	'Binary' => 'Binário',
	'Lists' => 'Listas',
	'Editor' => 'Editor',
	'E-mail' => 'E-mail',
	'From' => 'De',
	'Subject' => 'Assunto',
	'Send' => 'Enviar',
	'%d e-mail(s) have been sent.' => array('%d email enviado.', '%d emails enviados.'),
	'Webserver file %s' => 'Arquivo do servidor web %s',
	'File does not exist.' => 'Arquivo não existe.',
	'%d in total' => '%d no total',
	'Permanent login' => 'Salvar Senha',
	'Databases have been dropped.' => 'Bases de dados eliminadas.',
	'Search data in tables' => 'Buscar dados nas Tabelas',
	'schema' => 'esquema',
	'Schema' => 'Esquema',
	'Alter schema' => 'Modificar esquema',
	'Create schema' => 'Criar esquema',
	'Schema has been dropped.' => 'Esquema eliminado.',
	'Schema has been created.' => 'Esquema criado.',
	'Schema has been altered.' => 'Esquema modificado.',
	'Sequences' => 'Sequências',
	'Create sequence' => 'Criar sequências',
	'Alter sequence' => 'Modificar sequência',
	'Sequence has been dropped.' => 'Sequência eliminada.',
	'Sequence has been created.' => 'Sequência criada.',
	'Sequence has been altered.' => 'Sequência modificada.',
	'User types' => 'Tipos definido pelo usuário',
	'Create type' => 'Criar tipo',
	'Alter type' => 'Modificar tipo',
	'Type has been dropped.' => 'Tipo eliminado.',
	'Type has been created.' => 'Tipo criado.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+clique vezes sobre o valor para edita-lo.',
	'Use edit link to modify this value.' => 'Utilize o link modificar para alterar.',
	'last' => 'último',
	'From server' => 'Desde servidor',
	'System' => 'Motor de Base de dados',
	'Select data' => 'Selecionar dados',
	'Show structure' => 'Mostrar estrutura',
	'empty' => 'vazio',
	'Network' => 'Rede',
	'Geometry' => 'Geometria',
	'File exists.' => 'Arquivo já existe.',
	'Attachments' => 'Anexos',
	'%d query(s) executed OK.' => array('%d consulta sql executada corretamente.', '%d consultas sql executadas corretamente.'),
	'Show only errors' => 'Mostrar somente erros',
	'Refresh' => 'Atualizar',
	'Invalid schema.' => 'Esquema inválido.',
	'Please use one of the extensions %s.' => 'Por favor use uma das extensões %s.',
	'now' => 'agora',
	'ltr' => 'ltr',
);
